@@ -621,8 +621,8 @@ gnome_radio_window_cb (GtkApplication *app,
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(grid));
 	g_signal_connect (window, "destroy", G_CALLBACK(gtk_main_quit), NULL);
 #endif
-	gtk_window_set_title (GTK_WINDOW(window), _("Radio 16.0.43 - http://www.gnomeradio.org/ - https://wiki.gnome.org/Apps/Radio"));
-	gtk_window_set_default_size (GTK_WINDOW(window), 740, 580);
+	gtk_window_set_title (GTK_WINDOW(window), _("Radio 43.0 - http://www.gnomeradio.org/ - https://wiki.gnome.org/Apps/Radio"));
+	gtk_window_set_default_size (GTK_WINDOW(window), 800, 600);
 	gtk_window_maximize (GTK_WINDOW (window));
 	gnome_radio_app = create_gnome_radio_app();
 	gtk_widget_show(gnome_radio_app);
@@ -787,9 +787,7 @@ on_search_matches(GtkEntryCompletion *widget,
 	return FALSE;
 }
 
-int
-main (int argc,
-      char **argv)
+static void activate(GtkApplication *app, gpointer user_data)
 {
 	GtkWidget *window;
 	GtkWidget *widget, *vbox, *bbox, *button, *viewport, *image;
@@ -799,20 +797,18 @@ main (int argc,
 	GtkTreeIter iter;
 	GNOMERadioStationInfo *stationinfo, *localstation;
 	guint context_id;
-        GVariant *timestamp;
-        GTimeVal tv = { 0 };
-        const char *desc;
+  const char *desc;
 	bindtextdomain (GETTEXT_PACKAGE, GNOME_RADIO_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-	if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
-		return 1;
-	gtk_init (&argc, &argv);
+	// if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+	//	return 1;
+	// gtk_init (&argc, &argv);
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	/* give the window a 10px wide border */
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 	/* give it the title */
-	gtk_window_set_title (GTK_WINDOW (window), _("Radio 16.0.43 - http://www.gnomeradio.org/ - https://wiki.gnome.org/Apps/Radio"));
+	gtk_window_set_title (GTK_WINDOW (window), _("Radio 43.0 - http://www.gnomeradio.org/ - https://wiki.gnome.org/Apps/Radio"));
 	/* Connect the destroy event of the window with our on_destroy function
 	 * When the window is about to be destroyed we get a notificaiton and
 	 * stop the main GTK loop
@@ -1052,22 +1048,22 @@ main (int argc,
 	/* make sure that everything, window and label, are visible */
 	gtk_widget_show_all (window);
 
-	gst_init(&argc, &argv);
-
 	/* start the main loop */
 	gtk_main ();
 
-	return 0;
-#if 0
-	
-	app = gtk_application_new ("org.gnome.gnome-radio", G_APPLICATION_FLAGS_NONE);
+}
 
-	g_signal_connect (app, "activate", G_CALLBACK (gnome_radio_window_cb), NULL);
-	
+int main (int argc, char **argv)
+{
+  GtkApplication *app;
+  int status;
+  if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+		return 1;
+  gst_init(&argc, &argv);
+	app = gtk_application_new ("org.gnome.radio", G_APPLICATION_FLAGS_NONE);
+	g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
 	status = g_application_run (G_APPLICATION (app), argc, argv);
-
 	g_object_unref (app);
 
 	return status;
-#endif
 }
